<?php

namespace App\Http\Controllers\Auth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Otp;
use Session;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;

class ForgotPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset emails and
    | includes a trait which assists in sending these notifications from
    | your application to your users. Feel free to explore this trait.
    |
    */

    use SendsPasswordResetEmails;



    public function resetPassword(Request $request){
        $request->validate([
            'mobile_number' => 'required|digits:10',
        ],
        [
        'mobile_number.digits' => '10 अंको की मोबाइल संख्या डालें',
    ]);

        $info = User::where('mobile_number', $request->mobile_number)->first();
        if(is_null($info)){
            return redirect()->back()->with('error', 'रिकोड नहीं मिला?');
        }else{
            Session::put('resetPasswordMobileNumber', $request->mobile_number);
            return redirect()->route('setNewPassword');
        }
    }


    public function setNewPassword(){
        return view('auth.passwords.set_new_password');
    }


    public function postSetNewPassword(Request $request){
        $request->validate([
            'password' => 'required|min:6',
            'confirm_password' => 'required_with:password|same:password|min:6'
        ],
        [
        'password.min' => 'कृपया 6 अंकों का पासवर्ड दर्ज करें',
        'confirm_password.min' => 'कृपया 6 अंकों का पासवर्ड दर्ज करें',
        'confirm_password.same' => 'दोनों पासवर्ड का मिलान सही नहीं है'
    ]);
        $mobileNumber = Session::get('resetPasswordMobileNumber');
        $user = User::where('mobile_number', $mobileNumber)->first();

        if(is_null($user)){
            return redirect('login')->with('error', 'कुछ गलत हो गया है।');
    }else{
        $code = rand(111111, 999999);
        Session::put('Otp', $code);
        Session::put('newpassword', $request->password);
        $otp = new Otp;
        $otp->otp =  $code;
        $otp->status = 1;
        $otp->uniqid_id = uniqid();
        $otp->user_id = $user->id;
        if($otp->save()){
            return redirect()->route('resetPasswordOtpVerifiction')->with('success', 'ओटीपी सफलतापूर्वक भेजा गया है।');
        }else{
            Session::flush();
            return redirect('login')->with('error', 'कुछ गलत हो गया है।');
        }
    }
}


   public function otp(){
    return view('auth.passwords.otp');
   }

 public function resendotp(){
        $mobileNumber = Session::get('resetPasswordMobileNumber');
          $registered_user = User::where('mobile_number', $mobileNumber)->first();
                $code = rand(111111, 999999);
                Session::put('Otp', $code);
                $otp = new Otp;
                $otp->otp =  $code;
                $otp->status = 1;
                $otp->uniqid_id = uniqid();
                $otp->user_id = $registered_user->id;
                $otp->save();
                return redirect()->back()->with('success', 'ओटीपी सफलतापूर्वक भेजा गया है।');
      }

   public function postOtp(Request $request){
    $otp= $request->otp[0].$request->otp[1].$request->otp[2].$request->otp[3].$request->otp[4].$request->otp[5];
    $mobileNumber = Session::get('resetPasswordMobileNumber');
    $password = Session::get('newpassword');
    $user = User::where('mobile_number', $mobileNumber)->first();
    if(is_null($user)){
        Session::flush();
        return redirect('login')->with('error', 'कुछ गलत हो गया है।');
    }else{
        $value = Otp::where('user_id', $user->id)->where('status', '1')->orderBy('id','DESC')->first();
        if(is_null($value)){
            return redirect()->back()->with('error', 'कुछ गलत हो गया है।');
  }else{
    $otp1 =  $value->otp;
    if ($otp1 == $otp) {
        $otp_update = Otp::find($value->id);
        $otp_update->status = 2;
        $otp_update->save();
            $user->password =bcrypt($password);
            $user->save();
            Session::flush();
            return redirect('login')->with('success', 'पासवर्ड सफलतापूर्वक बदल गया!');
           }
    return redirect()->back()->with('error','ओटीपी अमान्य है।');
  }
}

    }
   }
