<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\VidhanSabha;
use App\Models\User;
use App\Models\UserDetail;
use Auth;
use Str;

class BoothAgentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $boothagent = User::where('status' ,'1')->whereHas('roles', function($q){
            $q->where('name', 'boothagent');
        })
        ->get();
        
        return view('admin.boothagent.index',compact('boothagent'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        return view('admin.boothagent.create',compact('vidhansabha'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
          
            'booth_name' => 'required',
            'name' => 'required',
            'email' => 'required',
            'mobile_number' => 'required|unique:users',
            'password' => 'required',
            'address' => 'required',
            
        ]);

        $user = new User;
        $user->vidhansabha_id=$request->vidhansabha;    
        $user->name=Str::upper($request->name);
        $user->email = $request->email;
        $user->status = 1;
        $user->mobile_number=$request->mobile_number;
        $user->password = bcrypt($request->password);
        $user->assignRole('boothagent');
        $user->unique_id=uniqid();
        $user->save();

        $user_detail = new UserDetail;
        $user_detail->user_id=$user->id;
        $user_detail->creator_id=Auth::user()->id;
        $user_detail->booth_name=Str::upper($request->booth_name);
        $user_detail->phone_no=$request->phone_no;
        $user_detail->address=$request->address;
        $user_detail->save();    

        session()->flash('success_msg', 'New Booth Agent has been created successfully');
        return redirect()->route('aboothagent.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=User::where('unique_id',$id)->value('id');
        $row=User::findorfail($id);
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        return view('admin.boothagent.edit',compact('row','vidhansabha'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $user =User::find($id);
        $this->validate($request, [
          
            'booth_name' => 'required',
            'name' => 'required',
            'email' => 'required',
            'mobile_number' => 'required|unique:users,mobile_number,'.$user->id,
            'address' => 'required',
            
        ]);

        
        $user->vidhansabha_id=$request->vidhansabha;    
        $user->name=$request->name;
        $user->email = $request->email;
        $user->mobile_number=$request->mobile_number;
        $user->assignRole('boothagent');  
        $user->save();

        $uid=UserDetail::where('user_id',$user->id)->value('id');

        $user_detail =UserDetail::find($uid);
        $user_detail->user_id=$user->id;
        $user_detail->booth_name=$request->booth_name;
        $user_detail->phone_no=$request->phone_no;
        $user_detail->address=$request->address;
        $user_detail->save();    

        session()->flash('success_msg','Booth Agent has been updated successfully');
        return redirect()->route('aboothagent.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user_id=User::where('unique_id',$id)->value('id');    
        $user=User::find($user_id);
        $user->status="2";
        $user->save();
        
        session()->flash('success_msg', 'Booth Agent has been deleted successfully');
        return back();
    }
}
