<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Company;
use Carbon\Carbon;
use Auth;

class CompanyController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $company= Company::where('status',1)->get();
        return view('admin.company.index',compact('company'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.company.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
          
			'company_name'=>'required',
        ]);
        
        $unique_id=uniqid();
            
            $company = new Company;         
            $company->status =1;       
            $company->company_name = $request->company_name;        
            $company->unique_id=$unique_id;
            if ($request->hasFile('company_image')) {
                $image = $request->file('company_image');
                $filename = $image->getClientOriginalName();
                $destinationPath = public_path('uploads/company_image');
                $image->move($destinationPath, $filename);
                $company->company_image= "uploads/company_image/" . $filename;
            }
            $company->save();  
            
        
            session()->flash('success_msg', 'created successfully');
            return redirect()->route('company.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=Company::where('unique_id',$id)->value('id');
        $row=Company::find($id);
        return view('admin.company.edit',compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
          
			'company_name'=>'required',
	
        ]);

            $company = Company::find($id);  
            $company->company_name = $request->company_name;
            if ($request->hasFile('company_image')) {
                $image = $request->file('company_image');
                $filename = $image->getClientOriginalName();
                $destinationPath = public_path('uploads/company_image');
                $image->move($destinationPath, $filename);
                $company->company_image= "uploads/company_image/" . $filename;
            }   
            $company->save();  
            
       
            session()->flash('success_msg', 'Update successfully');
            return redirect()->route('company.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $company_id=Company::where('unique_id',$id)->value('id');
        $company=Company::find($company_id);
        $company->status="2";
        $company->save();
        
        session()->flash('success_msg', 'Company has been deleted successfully');
        return back();
    }
}
