<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\VidhanSabha;
use App\Models\Category;
use App\Models\Inventory;
use App\Models\User;
use App\Models\UserDetail;
use App\Models\Notifications_List;
use Auth;
use Str;

class InventoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $inventory=Inventory::Where('status','1')->where('creator_id', '!=',  Auth::user()->id)->where('user_id', Auth::user()->id)->orderBy('received', 'ASC')->get();
        $inventoryList=Inventory::Where('status','1')->where('creator_id', Auth::user()->id)->orderBy('received', 'ASC')->get();
        return view('admin.inventory.index',compact('inventory','inventoryList'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        $category = Category::where('status' ,'1')->pluck('category_name', 'id')->toarray();
        $user=User::whereHas('roles', function($q){
            $q->where('name','boothagent');
        })->where('status',1)->pluck('name','id')->toArray();
        // $boothagent=User::whereHas('roles', function($q){
        //     $q->where('name','boothagent');
        // })->where('status',1)->get();


        return view('admin.inventory.create',compact('vidhansabha','category','user'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [

            'category_name' => 'required',


        ]);

        $inventory = new Inventory;
        $inventory->vidhansabha_id=$request->vidhansabha;
        $inventory->category_id=Str::upper($request->category_name);
        $inventory->user_id=Str::upper($request->name);
        $inventory->quantity=$request->quantity;
        $inventory->date=$request->date;
        $inventory->status = 1;
        $inventory->received = 1;
        $inventory->unique_id=uniqid();
        $inventory->creator_id=Auth::user()->id;
        $inventory->save();


 $info = new Notifications_List;
        $info->user_id = $inventory->user_id;
        $info->inventori_id = $inventory->id;
        $info->save();

        session()->flash('success_msg', 'New Booth Agent has been created successfully');
        return redirect()->route('ainventory.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        $category = Category::where('status' ,'1')->pluck('category_name', 'id')->toarray();

        $user=User::whereHas('roles', function($q){
            $q->where('name','admin');
        })->where('status',1)->pluck('name','id')->toArray();
        $id=Inventory::where('unique_id',$id)->value('id');
        $row=Inventory::find($id);
        return view('admin.inventory.edit',compact('row','vidhansabha','category','user'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [

            'category_name' => 'required',

        ]);
        $inventory=Inventory::find($id);
        $inventory->vidhansabha_id=$request->vidhansabha;
        $inventory->category_id=Str::upper($request->category_name);
        $inventory->user_id=Str::upper($request->name);
        $inventory->quantity=$request->quantity;
        $inventory->date=$request->date;
        $inventory->save();

         session()->flash('success_msg', 'Inventory has been updated successfully');
         return redirect()->route('ainventory.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $inventory_id=Inventory::where('unique_id',$id)->value('id');
        $inventory=Inventory::find($inventory_id);
        $inventory->status="2";
        $inventory->save();

        session()->flash('success_msg', 'Inventory has been deleted successfully');
        return back();
    }



     /**
     * Received the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

     public function received(Request $request,$id){
        $inventory = Inventory::where('unique_id',$id)->first();
        $inventory->received = 2;
        $inventory->remark = $request->remark;
        $inventory->save();
        session()->flash('success_msg', 'Inventory has been Received successfully');
        return redirect()->back();
     }
}
