<?php

namespace App\Http\Controllers\boothagent;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\VidhanSabha;
use App\Models\Category;
use App\Models\Inventory;
use App\Models\Requirement;
use App\Models\User;
use App\Models\UserDetail;
use App\Models\Notifications_List;
use Auth;
use Str;

class RequirementController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $requirement=Requirement::Where('status','1')->where('creator_id', Auth::user()->id)->get();
        return view('boothagent.requirement.index',compact('requirement'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        $category = Category::where('status' ,'1')->pluck('category_name', 'id')->toarray();
        $user=User::whereHas('roles', function($q){
            $q->where('name','admin');
        })->where('status',1)->pluck('name','id')->toArray();
    
        return view('boothagent.requirement.create',compact('vidhansabha','category','user'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
          
            'category_name' => 'required',
         
            
        ]);

        $requirement = new Requirement;
        $requirement->vidhansabha_id=$request->vidhansabha;    
        $requirement->category_id=Str::upper($request->category_name);
        $requirement->user_id=Str::upper($request->name);
        $requirement->quantity=$request->quantity;
        $requirement->date=$request->date;
        $requirement->remark=$request->remark;
        $requirement->status = 1;
        $requirement->unique_id=uniqid();
        $requirement->creator_id=Auth::user()->id;
        $requirement->save();  


         $info = new Notifications_List;
        $info->user_id = $requirement->user_id;
        $info->requirement_id = $requirement->id;
        $info->save();


        session()->flash('success_msg', 'नई आवश्यकता सफलतापूर्वक बनाई गई है');
        return redirect()->route('barequirement.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        $category = Category::where('status' ,'1')->pluck('category_name', 'id')->toarray();
      
        $user=User::whereHas('roles', function($q){
            $q->where('name','admin');
        })->where('status',1)->pluck('name','id')->toArray();
        $id=Requirement::where('unique_id',$id)->value('id');
        $row=Requirement::find($id);
        return view('boothagent.requirement.edit',compact('row','vidhansabha','category','user'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            
            'category_name' => 'required',
          
        ]);
        $requirement=Requirement::find($id);
        $requirement->vidhansabha_id=$request->vidhansabha;    
        $requirement->category_id=Str::upper($request->category_name);
        $requirement->user_id=Str::upper($request->name);
        $requirement->quantity=$request->quantity;
        $requirement->date=$request->date;
        $requirement->remark=$request->remark;
        $requirement->save();

         session()->flash('success_msg', 'आवश्यकता सफलतापूर्वक अपडेट कर दी गई है');
         return redirect()->route('barequirement.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $requirement_id=Requirement::where('unique_id',$id)->value('id'); 
        $requirement=Requirement::find($requirement_id);
        $requirement->status="2";
        $requirement->save();
        
        session()->flash('success_msg', 'आवश्यकता सफलतापूर्वक हटा दी गई है');
        return back();
    }
}
