<?php
namespace App\Http\Controllers\superadmin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Task;
use App\Models\VidhanSabha;
use App\Models\Notifications_List;
use Auth;

class TaskController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $task=Task::Where('status','1')->get();
        $tasklist=Task::Where('status','1')->where('creator_id', '!=',  Auth::user()->id)->get();
        return view('superadmin.task.index',compact('task','tasklist'));
    }


        /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vidhanSabha = VidhanSabha::Where('status', 1)->get();
        $user=User::whereHas('roles', function($q){
            $q->where('name','admin');
        })->where('status',1)->get();
        return view('superadmin.task.create', compact('vidhanSabha','user'));
    }





      /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [

            'title' => 'required',
            'vidhansabha' => 'required',
            'description' => 'required',
            'date' => 'required',
            'user' => 'required',

        ]);
        $task=new Task;
        $task->title=$request->title;
        $task->description=$request->description;
        $task->vidhansabha_id=$request->vidhansabha;
        $task->date=$request->date;
        $task->user_id=$request->user;
        $task->creator_id=Auth::user()->id;
        $task->status='1';
        $task->unique_id=uniqid();
        $task->save();

        $info = new Notifications_List;
        $info->user_id = $task->user_id;
        $info->task_id = $task->id;
        $info->save();



         session()->flash('success_msg', 'New Task has been created successfully');
         return redirect()->route('satask.index');
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=task::where('unique_id',$id)->value('id');
        $row=Task::find($id);
        $vidhanSabha = VidhanSabha::all();
        $user=User::whereHas('roles', function($q){
            $q->where('name','admin');
        })->where('status',1)->get();
        return view('superadmin.task.edit',compact('row','vidhanSabha','user'));
    }

/**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [

            'title' => 'required',
            'vidhansabha' => 'required',
            'description' => 'required',
            'date' => 'required',
            'user' => 'required',

        ]);
        $task=Task::find($id);
        $task->title=$request->title;
        $task->description=$request->description;
        $task->vidhansabha_id=$request->vidhansabha;
        $task->date=$request->date;
        $task->user_id=$request->user;
        $task->save();

         session()->flash('success_msg', 'Task has been updated successfully');
         return redirect()->route('satask.index');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $task_id=Task::where('unique_id',$id)->value('id');
        $task=Task::find($task_id);
        $task->status="2";
        $task->save();

        session()->flash('success_msg', 'Task has been deleted successfully');
        return back();
    }

}
